==> ember-0.5.0.tar.bz2: ember-0.5.0/src/components/ogre/terrain/TerrainArea.h <==
//
// C++ Interface: TerrainArea
//
// Description: 
//
//
// Author: Erik Hjortsberg <erik@katastrof.nu>, (C) 2005
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.//
//
#ifndef EMBEROGRETERRAINAREA_H
#define EMBEROGRETERRAINAREA_H

#include <sigc++/signal.h>
#include <Eris/Entity.h>

namespace Mercator
{
    class Area;
}

namespace EmberOgre {

class EmberEntity;

/**
@author Erik Hjortsberg
*/
class TerrainArea
{
public:
    TerrainArea(EmberEntity* entity);

    ~TerrainArea();
	bool init();
	
	inline Mercator::Area* getArea() const;
	inline void setArea(Mercator::Area* area);
	
	sigc::signal<void, TerrainArea*> EventAreaChanged;

protected:

	Mercator::Area* mArea;
	EmberEntity* mEntity;
	Eris::Entity::AttrChangedSlot mAttrChangedSlot;
	
	void attributeChanged(const std::string& attributeName, const Atlas::Message::Element& attributeValue);
	void entity_Moved();
	void observeEntity();
	bool parseArea();

};

Mercator::Area* TerrainArea::getArea() const { return mArea; }
void TerrainArea::setArea(Mercator::Area* area) { mArea = area; }


};

#endif

==> ember-0.5.2.tar.bz2: ember-0.5.2/src/components/ogre/terrain/TerrainArea.h <==
//
// C++ Interface: TerrainArea
//
// Description: 
//
//
// Author: Erik Hjortsberg <erik@katastrof.nu>, (C) 2005
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.//
//
#ifndef EMBEROGRETERRAINAREA_H
#define EMBEROGRETERRAINAREA_H

#include <sigc++/signal.h>
#include <Eris/Entity.h>

namespace Mercator
{
    class Area;
}

namespace EmberOgre {

class EmberEntity;

namespace Terrain {

/**
@author Erik Hjortsberg
*/
class TerrainArea
{
public:
    TerrainArea(EmberEntity* entity);

    ~TerrainArea();
	bool init();
	
	inline Mercator::Area* getArea() const;
	inline void setArea(Mercator::Area* area);
	
	sigc::signal<void, TerrainArea*> EventAreaChanged;

protected:

	Mercator::Area* mArea;
	EmberEntity* mEntity;
	Eris::Entity::AttrChangedSlot mAttrChangedSlot;
	
	void attributeChanged(const Atlas::Message::Element& attributeValue);
	void entity_Moved();
	void observeEntity();
	bool parseArea();

};

Mercator::Area* TerrainArea::getArea() const { return mArea; }
void TerrainArea::setArea(Mercator::Area* area) { mArea = area; }

}
};

#endif
